@@ -8,6 +8,7 @@ import numpy as np
 from scipy.stats import logistic
 from sklearn.datasets import make_classification
 
+print("HELLO, THERE!")
 
 class StreamGenerator:
     """ Data streams generator for both stationary and drifting data streams.
@@ -37,8 +38,8 @@ class StreamGenerator:
         the previously encountered concepts.
     weights : array-like, shape (n_classes, ) or tuple (only for 2 classes)
         If array - class weight for static imbalance,
-        if tuple - (n_drifts, concept_sigmoid_spacing, IR aplitude [0-1])
-        for generation of dynamically imbalanced streams.
+        if 3-valued tuple - (n_drifts, concept_sigmoid_spacing, IR amplitude
+        [0-1]) for generation of continous dynamically imbalanced streams, if 2-valued tuple - (mean value, standard deviation) for generation of discreete dynamically imbalanced streams.
 
     Attributes
     ----------
@@ -233,25 +234,49 @@ class StreamGenerator:
                 accumulator += treshold
         # If dynamic balance is given
         else:
-            (
-                self.n_balance_drifts,
-                self.class_sigmoid_spacing,
-                self.balance_amplitude,
-            ) = self.weights
+            if len(self.weights) == 3:
+                (
+                    self.n_balance_drifts,
+                    self.class_sigmoid_spacing,
+                    self.balance_amplitude,
+                ) = self.weights
 
-            period, self.class_probabilities = self._sigmoid(
-                self.class_sigmoid_spacing, self.n_balance_drifts
-            )
+                period, self.class_probabilities = self._sigmoid(
+                    self.class_sigmoid_spacing, self.n_balance_drifts
+                )
 
-            # Amplitude correction
-            self.class_probabilities -= 0.5
-            self.class_probabilities *= self.balance_amplitude
-            self.class_probabilities += 0.5
+                # Amplitude correction
+                self.class_probabilities -= 0.5
+                self.class_probabilities *= self.balance_amplitude
+                self.class_probabilities += 0.5
 
-            # Will it work?
-            self.class_selector = (
-                self.class_probabilities < self.balance_noise
-            ).astype(int)
+                print(self.class_probabilities.shape)
+
+                # Will it work?
+                self.class_selector = (
+                    self.class_probabilities < self.balance_noise
+                ).astype(int)
+            elif len(self.weights) == 2:
+                (
+                    self.mean_prior,
+                    self.std_prior
+                ) = self.weights
+
+                self.class_probabilities = np.random.normal(
+                    self.mean_prior,
+                    self.std_prior,
+                    self.n_chunks
+                )
+
+                self.class_selector = np.random.uniform(size=(self.n_chunks,
+                                                              self.chunk_size))
+
+                self.class_selector[:, 0] = 0
+                self.class_selector[:,-1] = 1
+
+                self.class_selector = (self.class_selector > self.class_probabilities[:,np.newaxis]).astype(int)
+
+                self.class_selector = np.ravel(self.class_selector)
 
         # Przypisanie klas i etykiet
         if self.n_drifts > 0:
@@ -323,9 +348,10 @@ class StreamGenerator:
             return None
 
     def __str__(self):
-        if type(self.y_flip) == tuple:
-            return "%s_css%i_rs%i_nd%i_ln%i_%i_d%i_%i" % (
+        if type(self.y_flip) == tuple and type(self.weights) != tuple:
+            return "%s_%s_css%i_rs%i_nd%i_ln%i_%i_d%i_%i" % (
                 "gr" if self.incremental is False else "inc",
+                "n" if self.recurring is False else "r",
                 999
                 if self.concept_sigmoid_spacing is None
                 else self.concept_sigmoid_spacing,
@@ -336,18 +362,73 @@ class StreamGenerator:
                 50 if self.weights is None else (self.weights[0] * 100),
                 int(self.chunk_size * self.n_chunks),
             )
-        else:
-            return "%s_css%i_rs%i_nd%i_ln%i_d%i_%i" % (
+        elif type(self.y_flip) != tuple and type(self.weights) != tuple:
+            return "%s_%s_css%i_rs%i_nd%i_ln%i_d%i_%i" % (
                 "gr" if self.incremental is False else "inc",
+                "n" if self.recurring is False else "r",
                 999
                 if self.concept_sigmoid_spacing is None
                 else self.concept_sigmoid_spacing,
                 self.random_state,
                 self.n_drifts,
                 int(self.y_flip * 100),
-                self.weights[0] * 100 if self.weights is not None else 0,
+                50 if self.weights is None else (self.weights[0] * 100),
                 int(self.chunk_size * self.n_chunks),
             )
+        elif type(self.y_flip) == tuple and type(self.weights) == tuple and len(self.weights) == 3:
+            return "%s_%s_css%i_rs%i_nd%i_ln%i_%i_dc%s_%i" % (
+                "gr" if self.incremental is False else "inc",
+                "n" if self.recurring is False else "r",
+                999
+                if self.concept_sigmoid_spacing is None
+                else self.concept_sigmoid_spacing,
+                self.random_state,
+                self.n_drifts,
+                int(self.y_flip[0] * 100),
+                int(self.y_flip[1] * 100),
+                ("%i_%i_%.0f" % (self.weights[0],self.weights[0],self.weights[1])),
+                int(self.chunk_size * self.n_chunks),
+            )
+        elif type(self.y_flip) != tuple and type(self.weights) == tuple and len(self.weights) == 3:
+            return "%s_%s_css%i_rs%i_nd%i_ln%i_dc%s_%i" % (
+                "gr" if self.incremental is False else "inc",
+                "n" if self.recurring is False else "r",
+                999
+                if self.concept_sigmoid_spacing is None
+                else self.concept_sigmoid_spacing,
+                self.random_state,
+                self.n_drifts,
+                int(self.y_flip * 100),
+                ("%i_%i_%.0f" % (self.weights[0],self.weights[0],self.weights[1])),
+                int(self.chunk_size * self.n_chunks)
+            )
+        elif type(self.y_flip) == tuple and type(self.weights) == tuple and len(self.weights) == 2:
+            return "%s_%s_css%i_rs%i_nd%i_ln%i_%i_dd%s_%i" % (
+                "gr" if self.incremental is False else "inc",
+                "n" if self.recurring is False else "r",
+                999
+                if self.concept_sigmoid_spacing is None
+                else self.concept_sigmoid_spacing,
+                self.random_state,
+                self.n_drifts,
+                int(self.y_flip[0] * 100),
+                int(self.y_flip[1] * 100),
+                ("%.0f_%.0f" % (self.weights[0]*100,self.weights[1]*100)),
+                int(self.chunk_size * self.n_chunks),
+            )
+        elif type(self.y_flip) != tuple and type(self.weights) == tuple and len(self.weights) == 2:
+            return "%s_%s_css%i_rs%i_nd%i_ln%i_dd%s_%i" % (
+                "gr" if self.incremental is False else "inc",
+                "n" if self.recurring is False else "r",
+                999
+                if self.concept_sigmoid_spacing is None
+                else self.concept_sigmoid_spacing,
+                self.random_state,
+                self.n_drifts,
+                int(self.y_flip * 100),
+                ("%.0f_%.0f" % (self.weights[0]*100,self.weights[1]*100)),
+                int(self.chunk_size * self.n_chunks)
+            )
 
     def save_to_arff(self, filepath):
         """ Save generated stream to the ARFF format file.
